<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="../src/core/about.ui" line="16"/>
        <source>About gnunet-qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/about.ui" line="100"/>
        <source>gnunet-qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/about.ui" line="107"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/about.ui" line="114"/>
        <source>Copyright (C) 2006, 2007 by Nils Durner and other contributing authors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/about.ui" line="121"/>
        <source>Released under the terms of the GNU General Public License.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/about.ui" line="168"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWnd</name>
    <message>
        <location filename="../src/plugins/config/config.ui" line="13"/>
        <source>Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="50"/>
        <source>Client settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="120"/>
        <source>Server settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="84"/>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="92"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="100"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="164"/>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="273"/>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="193"/>
        <source>CDE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="198"/>
        <source>Cleanlooks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="203"/>
        <source>Motif</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="208"/>
        <source>Plastique</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="213"/>
        <source>Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="218"/>
        <source>Windows XP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="249"/>
        <source>Stylesheet:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="278"/>
        <source>Coffee</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/config/config.ui" line="283"/>
        <source>Pagefold</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FSWnd</name>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="16"/>
        <source>Filesharing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="35"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="168"/>
        <source>Clear inactive downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="239"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="266"/>
        <source>Search and download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="410"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="301"/>
        <source>Search for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="342"/>
        <source>with anonymity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="375"/>
        <source>in Namespace:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="499"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="514"/>
        <source>Indexing will avoid copying the file into the GNUnet database.  Instead, GNUnet will try to access the specified file directly.  If that fails, a copy of the file will be created.  Indexing should be used if the local machine is unlikely to ever be compromised by an adversary and if the uploaded file will not be modified or moved in the future.  Indexing is more efficient than insertion.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="517"/>
        <source>Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="530"/>
        <source>Inserting a file means that an encrypted copy will be added to the GNUnet database.  Without the proper key (which is not stored in plaintext anywhere) the file cannot be decrypted.  Use this option for small files, files that will be modified soon, files that maybe moved or if you are afraid that an adversary may detect the file in plaintext on your machine (after compromising your machine).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="533"/>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="551"/>
        <source>Scope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="566"/>
        <source>Single file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="579"/>
        <source>Entire directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="599"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="611"/>
        <source>Anonymity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="621"/>
        <source>What level of sender-anonymity is desired when sharing this particular file?  0 allows direct connections (no anonymity).  Higher levels require increasing amounts of cover traffic per shared block, increasing your privacy at the expense of efficiency.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="696"/>
        <source>File-/Directoryname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="708"/>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="718"/>
        <source>Choose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="792"/>
        <source>Start publication process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="650"/>
        <source>Priority:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="54"/>
        <source>Searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="84"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="146"/>
        <source>Abort selected downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="149"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="193"/>
        <source>Publications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="236"/>
        <source>Clear completed publications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="820"/>
        <source>Open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="468"/>
        <source>Publication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="316"/>
        <source>Search term, e.g. &quot;GPL&quot; or &quot;application/jpg&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="618"/>
        <source>Desired anonymity level. 0 means no receiver anonymity (allows direct connection).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="352"/>
        <source>Specify the desired anonymity level for this download. A value of 0 means no receiver anonymity (allows direct connection).  Use higher values for increased privacy at the expense of performance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="390"/>
        <source>Restrict the search to a particular namespace. If empty, the global namespace is searched.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="511"/>
        <source>Index file(s), do not store in encrypted database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="527"/>
        <source>Insert file into encrypted database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="563"/>
        <source>Publish a single file only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="576"/>
        <source>Publish an entire directory including subdirectories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.ui" line="657"/>
        <source>Importantance of the file (used to prioritize data in the local datastore).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GAboutDlg</name>
    <message>
        <location filename="../src/core/aboutDlg.cc" line="39"/>
        <source>Version </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GAboutPlugin</name>
    <message>
        <location filename="../src/plugins/about/about.cc" line="53"/>
        <source>GNU&amp;#8216;s decentralized anonymous and censorship-resistant P2P framework.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="67"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="69"/>
        <source>Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="257"/>
        <source>Release notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="87"/>
        <source>Welcome to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="152"/>
        <source>About GNUnet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="160"/>
        <source>GNUnet developers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="170"/>
        <source>Code contributors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="205"/>
        <source>Artwork</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="216"/>
        <source>Translators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="235"/>
        <source>Package maintainers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="95"/>
        <source>gnunet-qt is an integrated user interface for GNUnet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="98"/>
        <source>Features</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="102"/>
        <source>Anonymous publication and retrieval of individual files as well as complete directory structures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="105"/>
        <source>Search results with thumbnail previews and extensive content information, e.g. author, subject, ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="108"/>
        <source>GNUnet network statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="114"/>
        <source>Further information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="119"/>
        <source>Documentation and Questions &amp; Answers from the GNUnet team: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="121"/>
        <source>GNUnet homepage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="125"/>
        <source>Help forum, blogs and extended documentation: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="127"/>
        <source>GNUnet community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="131"/>
        <source>Issue tracker: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/about/about.cc" line="133"/>
        <source>Mantis</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GFSDownloadController</name>
    <message>
        <location filename="../src/plugins/fs/downloadController.cc" line="42"/>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/downloadController.cc" line="46"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/downloadController.cc" line="50"/>
        <source>ETA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/downloadController.cc" line="48"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/downloadController.cc" line="53"/>
        <source>Destination path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/downloadController.cc" line="44"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GFSPlugin</name>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="378"/>
        <source>Search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="410"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="248"/>
        <source>No keyword specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="394"/>
        <source>File to publish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="397"/>
        <source>Choose a directory to publish:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="410"/>
        <source>No filename specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="270"/>
        <source>Failed to create namespace URI from `%s&apos;.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="434"/>
        <source>Download of &quot;%0&quot; queued.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="492"/>
        <source>started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="498"/>
        <source>active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="504"/>
        <source>stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="510"/>
        <source>completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="516"/>
        <source>aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="522"/>
        <source>error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="528"/>
        <source>suspended</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="534"/>
        <source>resumed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="420"/>
        <source>Publication of &quot;%0&quot; queued.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GFSSearchSummaryController</name>
    <message>
        <location filename="../src/plugins/fs/searchSummaryController.cc" line="51"/>
        <source>active</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GFSSearchSummaryModel</name>
    <message>
        <location filename="../src/plugins/fs/searchSummaryModel.cc" line="39"/>
        <source>Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/searchSummaryModel.cc" line="41"/>
        <source>Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/searchSummaryModel.cc" line="43"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GFSUploadController</name>
    <message>
        <location filename="../src/plugins/fs/uploadController.cc" line="56"/>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/uploadController.cc" line="57"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/uploadController.cc" line="58"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/uploadController.cc" line="118"/>
        <source>Internal error: failed to create meta data for publication.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GFSUploadDialog</name>
    <message>
        <location filename="../src/plugins/fs/uploadDialog.cc" line="71"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/uploadDialog.cc" line="72"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/uploadDialog.cc" line="95"/>
        <source>Keyword</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/uploadDialog.cc" line="222"/>
        <source>All graphics (*.bmp *.gif *.jpg *.jpeg *.png *.pbm *.pgm *.ppm *.xbm *.xpm);;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GGeneralPlugin</name>
    <message>
        <location filename="../src/plugins/general/general.cc" line="43"/>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="43"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="83"/>
        <source>Stop process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="85"/>
        <source>Server background process is running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="90"/>
        <source>Start process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="92"/>
        <source>Server background process is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="108"/>
        <source>Terminating server...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="110"/>
        <source>Launching server...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="121"/>
        <source>Terminating server failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="174"/>
        <source>Server launched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="175"/>
        <source>Server terminated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.cc" line="123"/>
        <source>Launching server failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GMainWindow</name>
    <message>
        <location filename="../src/core/wndMain.cc" line="71"/>
        <source>Number of connected peers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GSearchItemDelegate</name>
    <message>
        <location filename="../src/plugins/fs/searchItemDelegate.cc" line="78"/>
        <source>Retrieving content...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GStatsPlugin</name>
</context>
<context>
    <name>GStatsThread</name>
    <message>
        <location filename="../src/plugins/stats/statsThread.cc" line="63"/>
        <source>Error establishing connection with background process gnunetd.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/stats/statsThread.cc" line="82"/>
        <source>Error reading information from background process gnunetd.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/common/assert.cc" line="37"/>
        <source>An internal error has occured and gnunet-qt will shut down to prevent further damage.

Please report this problem to the GNUnet developers (see gnunet.org).

Detailed error information: assertion failed at %1:%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/assert.cc" line="40"/>
        <source>Fatal error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fshelper.cc" line="37"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fshelper.cc" line="39"/>
        <source>Unclassified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fshelper.cc" line="41"/>
        <source>Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs.cc" line="132"/>
        <source>Internal error: received unhandled event from FSUI.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/gstring.cc" line="150"/>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/gstring.cc" line="152"/>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/gstring.cc" line="154"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/gstring.cc" line="156"/>
        <source>Bytes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResultWnd</name>
    <message>
        <location filename="../src/plugins/fs/fs-search-result.ui" line="153"/>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-search-result.ui" line="99"/>
        <source>with anonymity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-search-result.ui" line="129"/>
        <source>Close search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-search-result.ui" line="92"/>
        <source>recursively</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WndAbout</name>
    <message>
        <location filename="../src/plugins/about/about.ui" line="13"/>
        <source>Welcome</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WndGeneral</name>
    <message>
        <location filename="../src/plugins/general/general.ui" line="13"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.ui" line="36"/>
        <source>Server process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.ui" line="89"/>
        <source>Server background process is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.ui" line="117"/>
        <source>Start process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.ui" line="138"/>
        <source>Running applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.ui" line="166"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/general/general.ui" line="171"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WndMain</name>
    <message>
        <location filename="../src/core/wndMain.ui" line="21"/>
        <source>gnunet-qt, GNU&apos;s Peer-To-Peer Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/wndMain.ui" line="41"/>
        <source>gnunet-qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/wndMain.ui" line="66"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/wndMain.ui" line="60"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/wndMain.ui" line="77"/>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/wndMain.ui" line="85"/>
        <source>&amp;Context help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/wndMain.ui" line="96"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WndStats</name>
    <message>
        <location filename="../src/plugins/stats/stats.ui" line="16"/>
        <source>Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/stats/stats.ui" line="41"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/stats/stats.ui" line="46"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dlgTextEditor</name>
    <message>
        <location filename="../src/plugins/fs/textEditor.ui" line="13"/>
        <source>Edit text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dlgUpload</name>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="13"/>
        <source>Edit file information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="32"/>
        <source>Meta-data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="198"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="62"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="91"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="117"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="127"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="173"/>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="243"/>
        <source>Keyword:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="477"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="484"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="303"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="318"/>
        <source>use keywords for individual files in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="331"/>
        <source>extract keywords and meta data from files in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="357"/>
        <source>Thumbnail preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/plugins/fs/fs-upload.ui" line="417"/>
        <source>Choose thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
